@@ -376,6 +376,35 @@ MHD_str_equal_caseless_n_ (const char * const str1,
 }
 
 
+/**
+ * Check two string for equality, ignoring case of US-ASCII letters and
+ * checking exactly @a len characters.
+ * Compares exactly @a len characters, including binary zero characters.
+ * @param str1 first string to compare
+ * @param str2 second string to compare
+ * @param len number of characters to compare
+ * @return non-zero if two strings are equal, zero otherwise.
+ */
+bool
+MHD_str_equal_caseless_bin_n_ (const char * const str1,
+                  const char * const str2,
+                  size_t len)
+{
+  size_t i;
+
+  for (i = 0; i < len; ++i)
+    {
+      const char c1 = str1[i];
+      const char c2 = str2[i];
+      if ( (c1 != c2) &&
+           (toasciilower (c1) != toasciilower (c2)) )
+        return 0;
+    }
+  return !0;
+}
+
+
+
 /**
  * Check whether @a str has case-insensitive @a token.
  * Token could be surrounded by spaces and tabs and delimited by comma.
