@@ -43,8 +43,9 @@ testStartError ()
   d = MHD_start_daemon (MHD_USE_ERROR_LOG, 0, NULL, NULL, NULL, NULL);
   if (NULL != d)
   {
+    MHD_stop_daemon (d);
     fprintf (stderr,
-             "Succeeded at binding to port 0?\n");
+             "Succeeded to start without MHD_AccessHandlerCallback?\n");
     return 1;
   }
   return 0;
@@ -56,6 +57,8 @@ apc_nothing (void *cls,
              const struct sockaddr *addr,
              socklen_t addrlen)
 {
+  (void)cls; (void)addr; (void)addrlen; /* Unused. Silent compiler warning. */
+
   return MHD_NO;
 }
 
@@ -65,6 +68,8 @@ apc_all (void *cls,
          const struct sockaddr *addr,
          socklen_t addrlen)
 {
+  (void)cls; (void)addr; (void)addrlen; /* Unused. Silent compiler warning. */
+
   return MHD_YES;
 }
 
@@ -78,6 +83,10 @@ ahc_nothing (void *cls,
              const char *upload_data, size_t *upload_data_size,
              void **unused)
 {
+  (void)cls;(void)connection;(void)url;          /* Unused. Silent compiler warning. */
+  (void)method;(void)version;(void)upload_data;  /* Unused. Silent compiler warning. */
+  (void)upload_data_size;(void)unused;           /* Unused. Silent compiler warning. */
+
   return MHD_NO;
 }
 
@@ -88,7 +97,7 @@ testStartStop ()
   struct MHD_Daemon *d;
 
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
-                        1080,
+                        0,
                         &apc_nothing, NULL,
                         &ahc_nothing, NULL,
                         MHD_OPTION_END);
@@ -96,7 +105,7 @@ testStartStop ()
   {
     fprintf (stderr,
              "Failed to start daemon on port %u\n",
-             1080);
+             0);
     exit (77);
   }
   MHD_stop_daemon (d);
@@ -113,7 +122,7 @@ testExternalRun ()
   int i;
 
   d = MHD_start_daemon (MHD_USE_ERROR_LOG,
-                        1081,
+                        0,
                         &apc_all, NULL,
                         &ahc_nothing, NULL,
                         MHD_OPTION_END);
@@ -122,7 +131,7 @@ testExternalRun ()
   {
     fprintf (stderr,
              "Failed to start daemon on port %u\n",
-             1081);
+             0);
     exit (77);
   }
   i = 0;
@@ -157,7 +166,7 @@ testThread ()
   struct MHD_Daemon *d;
 
   d = MHD_start_daemon (MHD_USE_ERROR_LOG | MHD_USE_INTERNAL_POLLING_THREAD,
-                        1082,
+                        0,
                         &apc_all, NULL,
                         &ahc_nothing, NULL,
                         MHD_OPTION_END);
@@ -186,7 +195,7 @@ testMultithread ()
   struct MHD_Daemon *d;
 
   d = MHD_start_daemon (MHD_USE_ERROR_LOG | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_THREAD_PER_CONNECTION,
-                        1083,
+                        0,
                         &apc_all, NULL,
                         &ahc_nothing, NULL,
                         MHD_OPTION_END);
@@ -195,7 +204,7 @@ testMultithread ()
   {
     fprintf (stderr,
              "Failed to start daemon on port %u\n",
-             1083);
+             0);
     exit (77);
   }
   if (MHD_run (d) != MHD_NO)
@@ -214,6 +223,7 @@ main (int argc,
       char *const *argv)
 {
   int errorCount = 0;
+  (void)argc; (void)argv; /* Unused. Silent compiler warning. */
 
   errorCount += testStartError ();
   errorCount += testStartStop ();
