@@ -51,6 +51,8 @@
 #include <windows.h>
 #endif
 
+#include "mhd_has_in_name.h"
+
 #if defined(CPU_COUNT) && (CPU_COUNT+0) < 2
 #undef CPU_COUNT
 #endif
@@ -415,8 +417,9 @@ main (int argc, char *const *argv)
     }
 #endif /* _WIN32 */
 
-  oneone = (NULL != strrchr (argv[0], (int) '/')) ?
-    (NULL != strstr (strrchr (argv[0], (int) '/'), "11")) : 0;
+  if (NULL == argv || 0 == argv[0])
+    return 99;
+  oneone = has_in_name (argv[0], "11");
   if (MHD_YES == MHD_is_feature_supported(MHD_FEATURE_THREADS))
     {
       errorCount += testInternalGet ();
