@@ -32,6 +32,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include "mhd_has_in_name.h"
 
 #ifndef WINDOWS
 #include <unistd.h>
@@ -166,7 +167,7 @@ testMultithreadedGet ()
           curl_easy_setopt (c, CURLOPT_PORT, (long)port);
           curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
           curl_easy_setopt (c, CURLOPT_WRITEDATA, &cbc[i]);
-          curl_easy_setopt (c, CURLOPT_FAILONERROR, 1);
+          curl_easy_setopt (c, CURLOPT_FAILONERROR, 1L);
           curl_easy_setopt (c, CURLOPT_TIMEOUT, 150L);
           curl_easy_setopt (c, CURLOPT_FORBID_REUSE, 0L);
           curl_easy_setopt (c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
@@ -174,7 +175,7 @@ testMultithreadedGet ()
           /* NOTE: use of CONNECTTIMEOUT without also
            *   setting NOSIGNAL results in really weird
            *   crashes on my system! */
-          curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1);
+          curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
 
           errornum = curl_easy_perform (c);
           if (CURLE_OK == errornum)
@@ -273,7 +274,7 @@ testMultithreadedPoolGet ()
           curl_easy_setopt (c, CURLOPT_PORT, (long)port);
           curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
           curl_easy_setopt (c, CURLOPT_WRITEDATA, &cbc[i]);
-          curl_easy_setopt (c, CURLOPT_FAILONERROR, 1);
+          curl_easy_setopt (c, CURLOPT_FAILONERROR, 1L);
           curl_easy_setopt (c, CURLOPT_TIMEOUT, 150L);
           curl_easy_setopt (c, CURLOPT_FORBID_REUSE, 0L);
           curl_easy_setopt (c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
@@ -281,7 +282,7 @@ testMultithreadedPoolGet ()
           /* NOTE: use of CONNECTTIMEOUT without also
            *   setting NOSIGNAL results in really weird
            *   crashes on my system! */
-          curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1);
+          curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
 
           errornum = curl_easy_perform (c);
           if ( ( (CURLE_OK != errornum) && (i <  2) ) ||
@@ -339,8 +340,9 @@ main (int argc, char *const *argv)
   unsigned int errorCount = 0;
   (void)argc;   /* Unused. Silent compiler warning. */
 
-  oneone = (NULL != strrchr (argv[0], (int) '/')) ?
-    (NULL != strstr (strrchr (argv[0], (int) '/'), "11")) : 0;
+  if (NULL == argv || 0 == argv[0])
+    return 99;
+  oneone = has_in_name (argv[0], "11");
   if (0 != curl_global_init (CURL_GLOBAL_WIN32))
     return 2;
   errorCount |= testMultithreadedGet ();
