@@ -31,7 +31,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <gauger.h>
+#include "gauger.h"
+#include "mhd_has_in_name.h"
 
 #ifndef WINDOWS
 #include <unistd.h>
@@ -161,7 +162,7 @@ testInternalPost ()
       curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
       curl_easy_setopt (c, CURLOPT_POSTFIELDSIZE, strlen (POST_DATA));
       curl_easy_setopt (c, CURLOPT_POST, 1L);
-      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1);
+      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1L);
       curl_easy_setopt (c, CURLOPT_TIMEOUT, 150L);
       if (oneone)
         curl_easy_setopt (c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
@@ -171,7 +172,7 @@ testInternalPost ()
       /* NOTE: use of CONNECTTIMEOUT without also
        *   setting NOSIGNAL results in really weird
        *   crashes on my system! */
-      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1);
+      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
       if (CURLE_OK != (errornum = curl_easy_perform (c)))
         {
           fprintf (stderr,
@@ -249,7 +250,7 @@ testMultithreadedPost ()
       curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
       curl_easy_setopt (c, CURLOPT_POSTFIELDSIZE, strlen (POST_DATA));
       curl_easy_setopt (c, CURLOPT_POST, 1L);
-      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1);
+      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1L);
       curl_easy_setopt (c, CURLOPT_TIMEOUT, 150L);
       if (oneone)
         curl_easy_setopt (c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
@@ -259,7 +260,7 @@ testMultithreadedPost ()
       /* NOTE: use of CONNECTTIMEOUT without also
        *   setting NOSIGNAL results in really weird
        *   crashes on my system! */
-      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1);
+      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
       if (CURLE_OK != (errornum = curl_easy_perform (c)))
         {
           fprintf (stderr,
@@ -336,7 +337,7 @@ testMultithreadedPoolPost ()
       curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
       curl_easy_setopt (c, CURLOPT_POSTFIELDSIZE, strlen (POST_DATA));
       curl_easy_setopt (c, CURLOPT_POST, 1L);
-      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1);
+      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1L);
       curl_easy_setopt (c, CURLOPT_TIMEOUT, 150L);
       if (oneone)
         curl_easy_setopt (c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
@@ -346,7 +347,7 @@ testMultithreadedPoolPost ()
       /* NOTE: use of CONNECTTIMEOUT without also
        *   setting NOSIGNAL results in really weird
        *   crashes on my system! */
-      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1);
+      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
       if (CURLE_OK != (errornum = curl_easy_perform (c)))
         {
           fprintf (stderr,
@@ -446,7 +447,7 @@ testExternalPost ()
       curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
       curl_easy_setopt (c, CURLOPT_POSTFIELDSIZE, strlen (POST_DATA));
       curl_easy_setopt (c, CURLOPT_POST, 1L);
-      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1);
+      curl_easy_setopt (c, CURLOPT_FAILONERROR, 1L);
       curl_easy_setopt (c, CURLOPT_TIMEOUT, 150L);
       if (oneone)
         curl_easy_setopt (c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
@@ -456,7 +457,7 @@ testExternalPost ()
       /* NOTE: use of CONNECTTIMEOUT without also
        *   setting NOSIGNAL results in really weird
        *   crashes on my system! */
-      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1);
+      curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
       mret = curl_multi_add_handle (multi, c);
       if (mret != CURLM_OK)
         {
@@ -579,8 +580,9 @@ main (int argc, char *const *argv)
   unsigned int errorCount = 0;
   (void)argc;   /* Unused. Silent compiler warning. */
 
-  oneone = (NULL != strrchr (argv[0], (int) '/')) ?
-    (NULL != strstr (strrchr (argv[0], (int) '/'), "11")) : 0;
+  if (NULL == argv || 0 == argv[0])
+    return 99;
+  oneone = has_in_name (argv[0], "11");
   if (0 != curl_global_init (CURL_GLOBAL_WIN32))
     return 2;
   if (MHD_YES == MHD_is_feature_supported(MHD_FEATURE_THREADS))
